



////////////////////////////////////////////////
//                                            //
// Self-Enforcing Powersharing in Weak States //
// Roessler and Ohls                          //
// International Organization 2018            //
//                                            //
////////////////////////////////////////////////

////////////////////////////////////////////////
// Unless otherwise specified, use this datafile: 
use selfenforcing_powersharing_epr2014.dta, clear

////////////////////////////////////////////////
// calculating threat capabilities and        //
// quad category IVs                          //
////////////////////////////////////////////////


////////////////////////////////////////
// distance and size

// ruling group distance
sort cowcode year
by cowcode year: gen temp_distance_ruling = distancecapitalcentroid if ruling_group==1
by cowcode year: egen distance_ruling = max(temp_distance_ruling)

// scale by max distance, reverse so closer gets higher values
sum distancecapitalcentroid, meanonly
gen dist_scaled = (distancecapitalcentroid - r(min)) / ( r(max)-r(min))
gen dist_rev = (1-dist_scaled)

sum distancecapitalcentroid, meanonly  
gen dist_ruling_scaled = (distance_ruling - r(min)) / ( r(max)-r(min))  
gen dist_ruling_rev = (1-dist_ruling_scaled)

// ruling group size
sort cowcode year
by cowcode year: gen temp_size_ruling = groupsize if ruling_group==1
by cowcode year: egen size_ruling = max(temp_size_ruling)

// scale by max size
sum groupsize, meanonly
gen size_scaled = (groupsize - r(min)) / ( r(max)-r(min))

sum groupsize, meanonly  
gen size_ruling_scaled = (size_ruling - r(min)) / ( r(max)-r(min)) 


////////////////////////////////////////
// threat capabilities variables

// combine into threat capabilities
gen threat = (dist_rev + size_scaled)/2
gen threat_ruling = (dist_ruling_rev + size_ruling_scaled)/2

// create lags
sort cowgroupid year
by cowgroupid: gen threat_lag = threat[_n-1]
by cowgroupid: gen threat_ruling_lag = threat_ruling[_n-1]


////////////////////////////////////////
// quad-category IVs

gen HH_cut = .
replace HH_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace HH_cut = 1 if (threat_lag >= r(p50)) & (threat_ruling_lag >= r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen HL_cut = .
replace HL_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace HL_cut = 1 if (threat_lag < r(p50)) & (threat_ruling_lag >= r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen LH_cut = .
replace LH_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace LH_cut = 1 if (threat_lag >= r(p50)) & (threat_ruling_lag < r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen LL_cut = .
replace LL_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace LL_cut = 1 if (threat_lag < r(p50)) & (threat_ruling_lag < r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)





////////////////////////////////////////////////
// main paper models                          //
////////////////////////////////////////////////


////////////////////////////////////////
// Ethnic Powersharing results (Table 1)

// EP-1
logit status_egip HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// EP-2
logit status_egip HL_cut LH_cut LL_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// EP-3
logit status_egip HH_cut status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// EP-4
logit status_egip HL_cut LH_cut LL_cut status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// EP-5
logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// EP-6
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)



/////////////////////////
// Coup results (Table 2)

// SC-1
logit group_s_coup HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// SC-2
logit group_s_coup HL_cut LH_cut LL_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// SC-3
logit group_s_coup HH_cut group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// SC-4
logit group_s_coup HL_cut LH_cut LL_cut group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// SC-5
logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// SC-6
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


//////////////////////////////
// Civil War results (Table 3)

// CW-1
logit group_rebel HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// CW-2
logit group_rebel HL_cut LH_cut LL_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// CW-3
logit group_rebel HH_cut group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// CW-4
logit group_rebel HL_cut LH_cut LL_cut group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// CW-5
logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
// CW-6
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

/////////////////////////////////////////////////////////
// Distribution of Quad-Categories (Figure 2)
 
tab HH_cut if ruling_group_l==0 & isrelevant_l==1
tab HL_cut if ruling_group_l==0 & isrelevant_l==1
tab LH_cut if ruling_group_l==0 & isrelevant_l==1
tab LL_cut if ruling_group_l==0 & isrelevant_l==1


/////////////////////////////////////////////////////////
// Ethnic Powersharing predicted Probabilities (Figure 3)

capture drop b1-b11
capture drop b12
capture drop b13
capture drop b14

estsimp logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

// upper left
setx HL_cut 0 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean year mean
simqi
// upper right
setx HL_cut 1 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean year mean
simqi
// lower left
setx HL_cut 0 LH_cut 1 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean year mean
simqi
// lower right
setx HL_cut 0 LH_cut 0 LL_cut 1 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean year mean
simqi


//////////////////////////////////////////
// Coup predicted probabilities (Figure 3)

capture drop b1-b11
capture drop b12
capture drop b13
capture drop b14

estsimp logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

// upper left
setx HL_cut 0 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean pastcoup mean year mean
simqi
// upper right
setx HL_cut 1 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean pastcoup mean year mean
simqi
// lower left
setx HL_cut 0 LH_cut 1 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean pastcoup mean year mean
simqi
// lower right
setx HL_cut 0 LH_cut 0 LL_cut 1 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean pastcoup mean year mean
simqi


///////////////////////////////////////////////
// Civil War predicted probabilities (Figure 3)

capture drop b1-b11
capture drop b12
capture drop b13
capture drop b14

estsimp logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

// upper left
setx HL_cut 0 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean ongoing_rebellion mean pastconflict mean year mean
simqi
// upper right
setx HL_cut 1 LH_cut 0 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean ongoing_rebellion mean pastconflict mean year mean
simqi
// lower left
setx HL_cut 0 LH_cut 1 LL_cut 0 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean ongoing_rebellion mean pastconflict mean year mean
simqi
// lower right
setx HL_cut 0 LH_cut 0 LL_cut 1 lgdppc_l mean lpop_l mean total_relevant_groups mean institutionalized_l mean french mean cold_war mean ongoing_rebellion mean pastconflict mean year mean
simqi






////////////////////////////////////////////////
// appendix summary stats and models          //
////////////////////////////////////////////////


/////////////////////////////////////////////////////////
//////////////////Section 1//////////////////////////////
/////////////////////////////////////////////////////////


/////////////////////////////////////////////////////
// Threat Capability summary statistics (Table A.1.1)

sum size_scaled size_ruling_scaled dist_rev dist_ruling_rev threat threat_ruling
centile size_scaled size_ruling_scaled dist_rev dist_ruling_rev threat threat_ruling


/////////////////////////////////////////////////////
// Quad Category IVs summary statistics (Table A.1.2)

sum HH_cut HL_cut LH_cut LL_cut if ruling_group==0 & isrelevant==1


////////////////////////////////////////////////////////////////////////////////
// Ethnic Powersharing, Coup, and Civil War DVs summary statistics (Table A.1.3)

sum status_egip group_s_coup group_rebel if ruling_group==0 & isrelevant==1


////////////////////////////////////////////////////
// Control Variable summary statistics (Table A.1.4)

sum lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war pastcoup pastconflict ongoing_rebellion year
centile lgdppc_l lpop_l total_relevant_groups year



/////////////////////////////////////////////////////////
//////////////////Section 2//////////////////////////////
/////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////
// Table A.2.1 ethnic configurations from Fearon
// Note: These models use a different dataset. Dataset name: selfenforcing_powersharing_sensitivity_analysis_Fearon_data.dta
// Threat capabilities are calculated taking arithmetic mean of inverse of distance and group size, same as main models
// Unit of observation is not EPR_ETH groups but groups from Fearon (2003) that match with EPR 3.0

///////////////////////////////////////////////////////////////////////////
// calculating threat capabilities and                                   //
// quad category IVs from Fearon data using                              //
use  selfenforcing_powersharing_sensitivity_analysis_Fearon_data.dta, clear       //
///////////////////////////////////////////////////////////////////////////


**creating lag of ruling group 
sort group year
by group: gen ruling_group_lag = ruling_group[_n-1]
label variable ruling_group_lag "Ruling Group Lag (in Previous Year)

**generate centroid distance of the ruling group for given year 
sort country year group
by country year: gen c_distance_ruling = centroid_distance if ruling_group==1
by country year: egen c_distance_r = max(c_distance_r)
drop c_distance_ruling
label variable c_distance_r "ruling_group centroid distance"

** generating size of the ruling group for given year 

sort country year group

by country year: gen size_ruling = group_size if ruling_group==1
by country year: egen size_r = max(size_ruling)
drop size_ruling
label variable size_r "ruling_group size as proportion of total population from Fearon"

**Rescale size variables 0 to 1
su group_size, meanonly
gen new_group_size = (group_size - r(min))/(r(max) - r(min)) 
label variable new_group_size "size rescaled 0 to 1"
su size_r, meanonly
gen new_size_r = (size_r - r(min))/(r(max) - r(min)) 
label variable new_size_r "size_r rescaled 0 to 1"

**Rescale centroid distance 0 to 1
su centroid_distance, meanonly
gen new_c_distance = (centroid_distance - r(min))/(r(max) - r(min))
su c_distance_r, meanonly 
gen new_c_distance_r = (c_distance_r - r(min))/(r(max) - r(min)) 

**Take inverse of new centroid distance and new centroid distance ruler so large values are closer to center
gen inverse_c_distance =(1-new_c_distance)
gen inverse_c_distance_r=(1-new_c_distance_r)
label variable inverse_c_distance_r "inverse of new_c_distance_r so high values indicate closer to capital"

**Calculate threat capabilities taking arithmetic mean of centroid distance and group size
gen threat = (inverse_c_distance + new_group_size)/2
label variable threat "non ruling group threat capabilities with centroid distance measure"
gen threat_ruling = (inverse_c_distance_r + new_size_r)/2
label variable threat_ruling "ruling group threat capabilities with centroid distance measure"

**Lag threat capabilities using centroid distance
sort country group year
by country: gen threat_lag = threat[_n-1]
label variable threat_lag "1 year lag of threat"
sort country group year
by country: gen threat_ruling_lag = threat_ruling[_n-1]
label variable threat_ruling_lag "1 year lag of threat_ruling"

// creating ALTERNATIVE quad variables measure, fully divided
//NOTE: ruling group first, opposition group second

gen HH_cut = .
replace HH_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace HH_cut = 1 if (threat_lag >= r(p50)) & (threat_ruling_lag >= r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen HL_cut = .
replace HL_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace HL_cut = 1 if (threat_lag < r(p50)) & (threat_ruling_lag >= r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen LH_cut = .
replace LH_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace LH_cut = 1 if (threat_lag >= r(p50)) & (threat_ruling_lag < r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)

gen LL_cut = .
replace LL_cut = 0 if threat_lag !=. & threat_ruling_lag != .
sum threat_lag, detail
replace LL_cut = 1 if (threat_lag < r(p50)) & (threat_ruling_lag < r(p50)) & (threat_lag !=.) & (threat_ruling_lag !=.)


// Models for Table A.2.1 ethnic configurations from Fearon
// Also note slight difference in some of the variables to ensure they are compatible with Fearon (2003)

logit egip HH_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war year egip_y egip_y2 egip_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)
logit egip HL_cut LH_cut LL_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war year egip_y egip_y2 egip_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war pastcoup year group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war pastcoup year group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war ongoing_rebellion pastconflict year group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdpcapl lpopl ef institutionalized_regimel french cold_war ongoing_rebellion pastconflict year group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & isrelevant_l==1, cluster(cowcode)



/////////////////////////////////////////////////////////
// Table A.2.2 independence group configurations
use "selfenforcing_powersharing_epr2014.dta", clear


logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1 & independence_group==1, cluster(cowcode)



/////////////////////////////////////////////////////////
//////////////////Section 3//////////////////////////////
/////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////
// Table A.3.1.1 minimum group distance capabilities

logit status_egip HH_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_min LH_min LL_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_min LH_min LL_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_min LH_min LL_min lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.1.2 geometric mean capabilities

logit status_egip HH_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_geo LH_geo LL_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_geo LH_geo LL_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_geo LH_geo LL_geo lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.1.3 coalition capabilities

logit status_egip HH_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cutcoal LH_cutcoal LL_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cutcoal LH_cutcoal LL_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cutcoal LH_cutcoal LL_cutcoal lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.1.4 country-relative capabilities

logit status_egip HH_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_crel LH_crel LL_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_crel LH_crel LL_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_crel LH_crel LL_crel lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.2.1 rebellion onset with alt measure--onset_ko_flag

logit onset_ko_flag HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict onset_ko_flag_y onset_ko_flag_y2 onset_ko_flag_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit onset_ko_flag HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict onset_ko_flag_y onset_ko_flag_y2 onset_ko_flag_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.2.2 rebellion incidence (rather than onset) with both measures

logit group_rebel_incidence HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_incidence_y group_rebel_incidence_y2 group_rebel_incidence_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel_incidence HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict group_rebel_incidence_y group_rebel_incidence_y2 group_rebel_incidence_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit incidence_flag HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict incidence_flag_y incidence_flag_y2 incidence_flag_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit incidence_flag HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict incidence_flag_y incidence_flag_y2 incidence_flag_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.3 total coups (rather than successful-only)

logit group_t_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_t_coup_y group_t_coup_y2 group_t_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_t_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup group_t_coup_y group_t_coup_y2 group_t_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.1 controlling for extant levels of powersharing

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year non_ruling_egips status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year non_ruling_egips status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year non_ruling_egipyn status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year non_ruling_egipyn status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.2 controlling for British colonization

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l british cold_war year ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.3 controlling for ethnic kin abroad (transnational ethnic kin)

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year tek_egip ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.4 controlling for social distance (common religion, common language, common race)

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year com_relig_primary com_lang_primary com_race_primary ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.5 controlling for historical determinants of size and shape (1850 population density, distance from the coast/trade)

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pop_1850 distance_coast ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.6 controlling for determinants of ethnic fractionalization (elevation variation, land quality variation)

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality  pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality  pastcoup group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality  ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year elevation_variation land_quality ongoing_rebellion pastconflict group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.4.7 controlling for interactive effects of past outcomes

logit status_egip HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year group_s_coup_lag group_rebel_lag status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit status_egip HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year group_s_coup_lag group_rebel_lag status_egip_y status_egip_y2 status_egip_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup status_egip_lag group_rebel_lag group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year pastcoup status_egip_lag group_rebel_lag group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict status_egip_lag group_s_coup_lag group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdppc_l lpop_l total_relevant_groups institutionalized_l french cold_war year ongoing_rebellion pastconflict status_egip_lag group_s_coup_lag group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)


/////////////////////////////////////////////////////////
// Table A.3.5.1-4 EPR 3.0
// These models use EPR 3.0
use selfenforcing_powersharing_epr_3.0.dta, clear
// Threat capabilities measures are calculated same way as EPR 2014

///////////////////////////////////
/// Table A.3.5.1

sum HH_cut HL_cut LH_cut LL_cut if ruling_group==0 & relevant==1

/// Table A.3.5.2
logit egip HH_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit egip HL_cut LH_cut LL_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)

logit egip HH_cut egip_y egip_y2 egip_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit egip HL_cut LH_cut LL_cut egip_y egip_y2 egip_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)

logit egip HH_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war year egip_y egip_y2 egip_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit egip HL_cut LH_cut LL_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war year egip_y egip_y2 egip_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)


/// Table A.3.5.3: Coup main models 
logit group_s_coup HH_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)

logit group_s_coup HH_cut group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)


logit group_s_coup HH_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war pastcoup year group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_s_coup HL_cut LH_cut LL_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war pastcoup year group_s_coup_y group_s_coup_y2 group_s_coup_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)


/// Table A3.5.4: Rebellion main models 
logit group_rebel HH_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)

logit group_rebel HH_cut group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)

logit group_rebel HH_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war ongoing_rebellion pastconflict year group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)
logit group_rebel HL_cut LH_cut LL_cut lgdpcapl lpopl  total_groups institutionalized_regimel french cold_war ongoing_rebellion pastconflict year group_rebel_y group_rebel_y2 group_rebel_y3 if ruling_group_lag==0 & relevant_l==1, cluster(cowcode)




////////////////////////////////////////////////////////
//// generating list of groups in the sample

gen insample = .

logit status_egip HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
replace insample=1 if e(sample)

logit group_s_coup HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
replace insample=1 if e(sample)

logit group_rebel HH_cut if ruling_group_l==0 & isrelevant_l==1, cluster(cowcode)
replace insample=1 if e(sample)






